@@ -17,7 +17,7 @@
 #
 #' Graphical posterior predictive checks
 #' 
-#' Interface to the \link[bayesplot]{PPC} (posterior predictive checking) module
+#' Interface to the \link[bayesplot:PPC-overview]{PPC} (posterior predictive checking) module
 #' in the \pkg{\link{bayesplot}} package, providing various plots comparing the 
 #' observed outcome variable \eqn{y} to simulated datasets \eqn{y^{rep}}{yrep} 
 #' from the posterior predictive distribution. The \code{pp_check} method for 
@@ -37,8 +37,8 @@
 #' @template reference-bayesvis
 #' @template args-stanreg-object
 #' @param plotfun A character string naming the \pkg{bayesplot} 
-#'   \link[bayesplot]{PPC} function to use. The default is to call
-#'   \code{\link[bayesplot]{ppc_dens_overlay}}. \code{plotfun} can be specified
+#'   \link[bayesplot:PPC-overview]{PPC} function to use. The default is to call
+#'   \code{\link[bayesplot:PPC-distributions]{ppc_dens_overlay}}. \code{plotfun} can be specified
 #'   either as the full name of a \pkg{bayesplot} plotting function (e.g.
 #'   \code{"ppc_hist"}) or can be abbreviated to the part of the name following
 #'   the \code{"ppc_"} prefix (e.g. \code{"hist"}). To get the names of all
@@ -66,7 +66,7 @@
 #' 
 #' @note For binomial data, plots of \eqn{y} and \eqn{y^{rep}}{yrep} show the 
 #'   proportion of 'successes' rather than the raw count. Also for binomial 
-#'   models see \code{\link[bayesplot]{ppc_error_binned}} for binned residual
+#'   models see \code{\link[bayesplot:PPC-errors]{ppc_error_binned}} for binned residual
 #'   plots.
 #' 
 #' @seealso 
@@ -78,13 +78,19 @@
 #'     the documentation for all the available plotting functions.
 #'   \item \code{\link{posterior_predict}} for drawing from the posterior 
 #'     predictive distribution. 
-#'   \item \code{\link[bayesplot]{color_scheme_set}} to change the color scheme 
+#'   \item \code{\link[bayesplot:bayesplot-colors]{color_scheme_set}} to change the color scheme 
 #'     of the plots.
 #' }
 #' 
-#' @examples 
-#' fit <- stan_glmer(mpg ~ wt + am + (1|cyl), data = mtcars, 
-#'                   iter = 400, chains = 2) # just to keep example quick
+#' @examples
+#' if (.Platform$OS.type != "windows" || .Platform$r_arch != "i386") {
+#' fit <- stan_glmer(
+#'   mpg ~ wt + am + (1|cyl), 
+#'   data = mtcars, 
+#'   iter = 400, # iter and chains small just to keep example quick
+#'   chains = 2, 
+#'   refresh = 0
+#' ) 
 #' 
 #' # Compare distribution of y to distributions of multiple yrep datasets
 #' pp_check(fit)
@@ -133,11 +139,13 @@
 #'   
 #' # Example of a PPC for ordinal models (stan_polr)
 #' fit2 <- stan_polr(tobgp ~ agegp, data = esoph, method = "probit",
-#'                   prior = R2(0.2, "mean"), init_r = 0.1)
+#'                   prior = R2(0.2, "mean"), init_r = 0.1, 
+#'                   refresh = 0)
 #' pp_check(fit2, plotfun = "bars", nreps = 500, prob = 0.5)
 #' pp_check(fit2, plotfun = "bars_grouped", group = esoph$agegp, 
 #'          nreps = 500, prob = 0.5)
 #' }
+#' }
 pp_check.stanreg <-
   function(object,
            plotfun = "dens_overlay",
@@ -201,7 +209,7 @@ is_binomial_ppc <- function(object, ...) {
            ...) {
     y <- get_y(object, ...)
     if (binned_resid_plot) {
-      yrep <- posterior_linpred(object, transform = TRUE, ...)
+      yrep <- posterior_epred(object, ...)
       yrep <- yrep[1:nreps, , drop = FALSE]
     } else {
       yrep <- posterior_predict(object, draws = nreps, seed = seed, ...)
@@ -329,13 +337,16 @@ is_binomial_ppc <- function(object, ...) {
   switch(fun,
     # DISTRIBUTIONS
     "dens_overlay" = nreps %ORifNULL% 50,
+    "dens_overlay_grouped" = nreps %ORifNULL% 50,
     "ecdf_overlay" = nreps %ORifNULL% 50,
+    "ecdf_overlay_grouped" = nreps %ORifNULL% 50,
     "hist" = nreps %ORifNULL% 8,
     "dens" = nreps %ORifNULL% 8,
     "boxplot" = nreps %ORifNULL% 8,
     "freqpoly" = nreps %ORifNULL% 8,
     "freqpoly_grouped" = nreps %ORifNULL% 3,
     "violin_grouped" = nreps, # NULL ok
+    "km_overlay" = nreps %ORifNULL% 50,
     
     # PREDICTIVE ERRORS
     "error_binned" = nreps %ORifNULL% 3,
@@ -354,6 +365,7 @@ is_binomial_ppc <- function(object, ...) {
     "stat" = .ignore_nreps(nreps),
     "stat_2d" = .ignore_nreps(nreps),
     "stat_grouped" = .ignore_nreps(nreps),
+    "stat_freqpoly" = .ignore_nreps(nreps),
     "stat_freqpoly_grouped" = .ignore_nreps(nreps),
     
     # INTERVALS
@@ -362,10 +374,8 @@ is_binomial_ppc <- function(object, ...) {
     "ribbon" = .ignore_nreps(nreps),
     "ribbon_grouped" = .ignore_nreps(nreps), 
     
-    # ROOTOGRAMS
+    # DISCRETE ONLY
     "rootogram" = nreps, # NULL ok
-    
-    # BAR PLOTS
     "bars" = nreps, # NULL ok
     "bars_grouped" = nreps, # NULL ok
     
