@@ -1,5 +1,5 @@
 # Part of the rstanarm package for estimating model parameters
-# Copyright (C) 2015, 2016, 2017 Trustees of Columbia University
+# Copyright (C) 2015, 2016, 2017, 2018, 2019 Trustees of Columbia University
 # 
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -15,10 +15,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-# tests can be run using devtools::test() or manually by loading testthat 
-# package and then running the code
-
-if (.Platform$OS.type == "windows") Sys.setenv(USE_CXX11 = 1) else Sys.setenv(USE_CXX14 = 1)
+Sys.setenv(USE_CXX14 = 1)
 set.seed(12345)
 
 MODELS_HOME <- "stan_files"
@@ -31,6 +28,16 @@ test_that("Stan programs are available", {
 
 library(rstan)
 Sys.unsetenv("R_TESTS")
+# TBB <- system.file("lib", .Platform$r_arch, package = "RcppParallel", mustWork = TRUE)
+# SH  <- system.file(ifelse(.Platform$OS.type == "windows", "libs", "lib"), 
+#                    .Platform$r_arch, package = "StanHeaders",  mustWork = TRUE)
+# Sys.setenv(LOCAL_LIBS = paste0("-L", shQuote(TBB), " -tbb -tbbmalloc ",
+#                                "-L", shQuote(SH) , " -lStanHeaders"))
+# Sys.setenv(PKG_LIBS = Sys.getenv("LOCAL_LIBS"))
+# Eigen <- dir(system.file("include", "stan", "math", "prim",
+#                          package = "StanHeaders", mustWork = TRUE),
+#              pattern = "Eigen.hpp$", full.names = TRUE, recursive = TRUE)[1]
+# Sys.setenv(PKG_CXXFLAGS = paste("-include", shQuote(Eigen)))
 
 functions <- sapply(dir(MODELS_HOME, pattern = "stan$", full.names = TRUE), function(f) {
   mc <- readLines(f)
@@ -43,9 +50,6 @@ functions <- sapply(dir(MODELS_HOME, pattern = "stan$", full.names = TRUE), func
   } else return(as.character(NULL))
 })
 names(functions) <- basename(names(functions))
-functions$polr.stan <- grep("csr_matrix_times_vector2", 
-                            functions$polr.stan, 
-                            value = TRUE, fixed = TRUE, invert = TRUE)
 functions <- c(unlist(lapply(file.path(MODELS_HOME, "functions", 
                              c("common_functions.stan",
                                "bernoulli_likelihoods.stan",
@@ -57,8 +61,9 @@ functions <- c(unlist(lapply(file.path(MODELS_HOME, "functions",
 model_code <- paste(c("functions {", functions, "}"), collapse = "\n")
 stanc_ret <- stanc(model_code = model_code, model_name = "Stan Functions",
                    allow_undefined = TRUE)
-expose_stan_functions(stanc_ret)
-Rcpp::sourceCpp(file.path(INCLUDE_DIR, "tests.cpp"))
+expose_stan_functions(stanc_ret, rebuild = TRUE, verbose = TRUE)
+# Rcpp::registerPlugin("rstan", rstan:::rstanplugin)
+# Rcpp::sourceCpp(file.path(INCLUDE_DIR, "tests.cpp"), rebuild = TRUE, verbose = TRUE)
 N <- 99L
 
 # bernoulli
@@ -271,17 +276,20 @@ test_that("inv_gaussian returns expected results", {
 # lm
 N <- 99L
 context("lm")
-test_that("ll_mvn_ols_qr_lp returns expected results", {
+test_that("ll_mvn_ols... returns expected results", {
   X <- matrix(rnorm(2 * N), N, 2)
+  X <- sweep(X, MARGIN = 2, STATS = colMeans(X), FUN = "-")
   y <- 1 + X %*% c(2:3) + rnorm(N)
   ols <- lm.fit(cbind(1,X), y)
   b <- coef(ols)
-  X <- sweep(X, MARGIN = 2, STATS = colMeans(X), FUN = "-")
   intercept <- 0.5
   beta <- rnorm(2)
   sigma <- rexp(1)
   SSR <- crossprod(residuals(ols))[1]
   ll <- sum(dnorm(y, intercept + X %*% beta, sigma, log = TRUE))
+  expect_true(all.equal(ll, ll_mvn_ols(c(intercept, beta), b, 
+                                       crossprod(cbind(1, X)), SSR, 
+                                       sigma, N)))
   decomposition <- qr(X)
   Q <- qr.Q(decomposition)
   R <- qr.R(decomposition)
@@ -389,16 +397,14 @@ if (require(lme4) && require(HSAUR3)) test_that("the Stan equivalent of lme4's Z
                  tol = 1e-14)
     
     parts <- extract_sparse_parts(Z)
-    Zb <- csr_matrix_times_vector2_test(nrow(Z), ncol(Z), parts$w, 
-                                        parts$v - 1L, parts$u - 1L, b)
-    expect_equal(Zb, as.vector(Z %*% b), tol = 1e-14)
+    Zb <- Z %*% b
     if (all(sapply(group$cnms, FUN = function(x) {
         length(x) == 1 && x == "(Intercept)"
       })) ) {
       V <- matrix(parts$v, nrow = sum(p), ncol = nrow(Z))
       expect_true(all(V == 
-                      t(as.matrix(as.data.frame(make_V(nrow(Z), nrow(V), parts$v - 1L))))))
-      expect_equal(Zb, apply(V, 2, FUN = function(v) sum(b[v])))
+                      t(as.matrix(as.data.frame(make_V(nrow(Z), nrow(V), parts$v))))))
+      expect_equal(Zb@x, apply(V, 2, FUN = function(v) sum(b[v])))
     }
   }
   test_lme4(glFormula(Reaction ~ Days + (Days | Subject), data = sleepstudy)$reTrms)
